Function cons_tuples
fn cons_tuples<I>(iterable: I) -> ConsTuples<<I as >::IntoIter>
where
I: IntoIterator
Create an iterator that maps for example iterators of
((A, B), C) to (A, B, C).
cons_tuplesfn cons_tuples<I>(iterable: I) -> ConsTuples<<I as >::IntoIter>
where
I: IntoIterator
Create an iterator that maps for example iterators of
((A, B), C) to (A, B, C).