Struct FilterMapOk

struct FilterMapOk<I, F> { ... }

An iterator adapter to filter and apply a transformation on values within a nested Result::Ok.

See .filter_map_ok() for more information.

Implementations

impl<I> IntoIterator for FilterMapOk<I, F>

fn into_iter(self: Self) -> I

impl<I, F> Debug for FilterMapOk<I, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<I, F> Freeze for FilterMapOk<I, F>

impl<I, F> RefUnwindSafe for FilterMapOk<I, F>

impl<I, F> Send for FilterMapOk<I, F>

impl<I, F> Sync for FilterMapOk<I, F>

impl<I, F> Unpin for FilterMapOk<I, F>

impl<I, F> UnsafeUnpin for FilterMapOk<I, F>

impl<I, F> UnwindSafe for FilterMapOk<I, F>

impl<I, F, T, U, E> DoubleEndedIterator for FilterMapOk<I, F>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>
fn rfold<Acc, Fold>(self: Self, init: Acc, fold_f: Fold) -> Acc
where
    Fold: FnMut(Acc, <Self as >::Item) -> Acc

impl<I, F, T, U, E> FusedIterator for FilterMapOk<I, F>

impl<I, F, T, U, E> Iterator for FilterMapOk<I, F>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn fold<Acc, Fold>(self: Self, init: Acc, fold_f: Fold) -> Acc
where
    Fold: FnMut(Acc, <Self as >::Item) -> Acc
fn collect<C>(self: Self) -> C
where
    C: FromIterator<<Self as >::Item>

impl<I: $crate::clone::Clone, F: $crate::clone::Clone> Clone for FilterMapOk<I, F>

fn clone(self: &Self) -> FilterMapOk<I, F>

impl<T> Any for FilterMapOk<I, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FilterMapOk<I, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FilterMapOk<I, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FilterMapOk<I, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FilterMapOk<I, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Itertools for FilterMapOk<I, F>

impl<T> ToOwned for FilterMapOk<I, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for FilterMapOk<I, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FilterMapOk<I, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FilterMapOk<I, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>