Struct FilterOk
struct FilterOk<I, F> { ... }
An iterator adapter to filter values within a nested Result::Ok.
See .filter_ok() for more information.
Implementations
impl<I> IntoIterator for FilterOk<I, F>
fn into_iter(self: Self) -> I
impl<I, F> Debug for FilterOk<I, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I, F> Freeze for FilterOk<I, F>
impl<I, F> RefUnwindSafe for FilterOk<I, F>
impl<I, F> Send for FilterOk<I, F>
impl<I, F> Sync for FilterOk<I, F>
impl<I, F> Unpin for FilterOk<I, F>
impl<I, F> UnsafeUnpin for FilterOk<I, F>
impl<I, F> UnwindSafe for FilterOk<I, F>
impl<I, F, T, E> DoubleEndedIterator for FilterOk<I, F>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn rfold<Acc, Fold>(self: Self, init: Acc, fold_f: Fold) -> Acc where Fold: FnMut(Acc, <Self as >::Item) -> Acc
impl<I, F, T, E> FusedIterator for FilterOk<I, F>
impl<I, F, T, E> Iterator for FilterOk<I, F>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn fold<Acc, Fold>(self: Self, init: Acc, fold_f: Fold) -> Acc where Fold: FnMut(Acc, <Self as >::Item) -> Accfn collect<C>(self: Self) -> C where C: FromIterator<<Self as >::Item>
impl<I: $crate::clone::Clone, F: $crate::clone::Clone> Clone for FilterOk<I, F>
fn clone(self: &Self) -> FilterOk<I, F>
impl<T> Any for FilterOk<I, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FilterOk<I, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FilterOk<I, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for FilterOk<I, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for FilterOk<I, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Itertools for FilterOk<I, F>
impl<T> ToOwned for FilterOk<I, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for FilterOk<I, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FilterOk<I, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FilterOk<I, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>