Struct FormatWith
struct FormatWith<'a, I, F> { ... }
Format all iterator elements lazily, separated by sep.
The format value can only be formatted once, after that the iterator is exhausted.
See .format_with() for more information.
Implementations
impl<'a, I, F> Freeze for FormatWith<'a, I, F>
impl<'a, I, F> RefUnwindSafe for FormatWith<'a, I, F>
impl<'a, I, F> Send for FormatWith<'a, I, F>
impl<'a, I, F> Sync for FormatWith<'a, I, F>
impl<'a, I, F> Unpin for FormatWith<'a, I, F>
impl<'a, I, F> UnsafeUnpin for FormatWith<'a, I, F>
impl<'a, I, F> UnwindSafe for FormatWith<'a, I, F>
impl<I, F> Clone for FormatWith<'_, I, F>
fn clone(self: &Self) -> Self
impl<I, F> Debug for FormatWith<'_, I, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I, F> Display for FormatWith<'_, I, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Any for FormatWith<'a, I, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for FormatWith<'a, I, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for FormatWith<'a, I, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for FormatWith<'a, I, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for FormatWith<'a, I, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for FormatWith<'a, I, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for FormatWith<'a, I, F>
fn to_string(self: &Self) -> String
impl<T, U> Into for FormatWith<'a, I, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for FormatWith<'a, I, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for FormatWith<'a, I, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>