Struct Permutations

struct Permutations<I: Iterator> { ... }

An iterator adaptor that iterates through all the k-permutations of the elements from an iterator.

See .permutations() for more information.

Implementations

impl<I> Clone for Permutations<I>

fn clone(self: &Self) -> Self

impl<I> Debug for Permutations<I>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<I> Freeze for Permutations<I>

impl<I> FusedIterator for Permutations<I>

impl<I> IntoIterator for Permutations<I>

fn into_iter(self: Self) -> I

impl<I> Iterator for Permutations<I>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn count(self: Self) -> usize
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<I> RefUnwindSafe for Permutations<I>

impl<I> Send for Permutations<I>

impl<I> Sync for Permutations<I>

impl<I> Unpin for Permutations<I>

impl<I> UnsafeUnpin for Permutations<I>

impl<I> UnwindSafe for Permutations<I>

impl<T> Any for Permutations<I>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Permutations<I>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Permutations<I>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Permutations<I>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Permutations<I>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Itertools for Permutations<I>

impl<T> ToOwned for Permutations<I>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Permutations<I>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Permutations<I>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Permutations<I>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>