Struct Positions
struct Positions<I, F> { ... }
An iterator adapter to get the positions of each element that matches a predicate.
See .positions() for more information.
Implementations
impl<I> IntoIterator for Positions<I, F>
fn into_iter(self: Self) -> I
impl<I, F> Debug for Positions<I, F>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I, F> DoubleEndedIterator for Positions<I, F>
fn next_back(self: &mut Self) -> Option<<Self as >::Item>fn rfold<B, G>(self: Self, init: B, func: G) -> B where G: FnMut(B, <Self as >::Item) -> B
impl<I, F> Freeze for Positions<I, F>
impl<I, F> FusedIterator for Positions<I, F>
impl<I, F> Iterator for Positions<I, F>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)fn fold<B, G>(self: Self, init: B, func: G) -> B where G: FnMut(B, <Self as >::Item) -> B
impl<I, F> RefUnwindSafe for Positions<I, F>
impl<I, F> Send for Positions<I, F>
impl<I, F> Sync for Positions<I, F>
impl<I, F> Unpin for Positions<I, F>
impl<I, F> UnsafeUnpin for Positions<I, F>
impl<I, F> UnwindSafe for Positions<I, F>
impl<I: $crate::clone::Clone, F: $crate::clone::Clone> Clone for Positions<I, F>
fn clone(self: &Self) -> Positions<I, F>
impl<T> Any for Positions<I, F>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Positions<I, F>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Positions<I, F>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Positions<I, F>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Positions<I, F>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Itertools for Positions<I, F>
impl<T> ToOwned for Positions<I, F>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Positions<I, F>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Positions<I, F>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Positions<I, F>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>