Struct Zip

struct Zip<T> { ... }

See multizip for more information.

Implementations

impl<A> DoubleEndedIterator for Zip<(A)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A> ExactSizeIterator for Zip<(A)>

impl<A> Iterator for Zip<(A)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B> DoubleEndedIterator for Zip<(A, B)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B> ExactSizeIterator for Zip<(A, B)>

impl<A, B> Iterator for Zip<(A, B)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C> DoubleEndedIterator for Zip<(A, B, C)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C> ExactSizeIterator for Zip<(A, B, C)>

impl<A, B, C> Iterator for Zip<(A, B, C)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D> DoubleEndedIterator for Zip<(A, B, C, D)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D> ExactSizeIterator for Zip<(A, B, C, D)>

impl<A, B, C, D> Iterator for Zip<(A, B, C, D)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D, E> DoubleEndedIterator for Zip<(A, B, C, D, E)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D, E> ExactSizeIterator for Zip<(A, B, C, D, E)>

impl<A, B, C, D, E> Iterator for Zip<(A, B, C, D, E)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D, E, F> DoubleEndedIterator for Zip<(A, B, C, D, E, F)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D, E, F> ExactSizeIterator for Zip<(A, B, C, D, E, F)>

impl<A, B, C, D, E, F> Iterator for Zip<(A, B, C, D, E, F)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D, E, F, G> DoubleEndedIterator for Zip<(A, B, C, D, E, F, G)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D, E, F, G> ExactSizeIterator for Zip<(A, B, C, D, E, F, G)>

impl<A, B, C, D, E, F, G> Iterator for Zip<(A, B, C, D, E, F, G)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D, E, F, G, H> DoubleEndedIterator for Zip<(A, B, C, D, E, F, G, H)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D, E, F, G, H> ExactSizeIterator for Zip<(A, B, C, D, E, F, G, H)>

impl<A, B, C, D, E, F, G, H> Iterator for Zip<(A, B, C, D, E, F, G, H)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D, E, F, G, H, I> DoubleEndedIterator for Zip<(A, B, C, D, E, F, G, H, I)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D, E, F, G, H, I> ExactSizeIterator for Zip<(A, B, C, D, E, F, G, H, I)>

impl<A, B, C, D, E, F, G, H, I> Iterator for Zip<(A, B, C, D, E, F, G, H, I)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D, E, F, G, H, I, J> DoubleEndedIterator for Zip<(A, B, C, D, E, F, G, H, I, J)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D, E, F, G, H, I, J> ExactSizeIterator for Zip<(A, B, C, D, E, F, G, H, I, J)>

impl<A, B, C, D, E, F, G, H, I, J> Iterator for Zip<(A, B, C, D, E, F, G, H, I, J)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D, E, F, G, H, I, J, K> DoubleEndedIterator for Zip<(A, B, C, D, E, F, G, H, I, J, K)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D, E, F, G, H, I, J, K> ExactSizeIterator for Zip<(A, B, C, D, E, F, G, H, I, J, K)>

impl<A, B, C, D, E, F, G, H, I, J, K> Iterator for Zip<(A, B, C, D, E, F, G, H, I, J, K)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A, B, C, D, E, F, G, H, I, J, K, L> DoubleEndedIterator for Zip<(A, B, C, D, E, F, G, H, I, J, K, L)>

fn next_back(self: &mut Self) -> Option<<Self as >::Item>

impl<A, B, C, D, E, F, G, H, I, J, K, L> ExactSizeIterator for Zip<(A, B, C, D, E, F, G, H, I, J, K, L)>

impl<A, B, C, D, E, F, G, H, I, J, K, L> Iterator for Zip<(A, B, C, D, E, F, G, H, I, J, K, L)>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<A: IntoIterator> From for Zip<(<A as >::IntoIter)>

fn from(t: (A)) -> Self

impl<A: IntoIterator, B: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter)>

fn from(t: (A, B)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter)>

fn from(t: (A, B, C)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter)>

fn from(t: (A, B, C, D)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator, E: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter, <E as >::IntoIter)>

fn from(t: (A, B, C, D, E)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator, E: IntoIterator, F: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter, <E as >::IntoIter, <F as >::IntoIter)>

fn from(t: (A, B, C, D, E, F)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator, E: IntoIterator, F: IntoIterator, G: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter, <E as >::IntoIter, <F as >::IntoIter, <G as >::IntoIter)>

fn from(t: (A, B, C, D, E, F, G)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator, E: IntoIterator, F: IntoIterator, G: IntoIterator, H: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter, <E as >::IntoIter, <F as >::IntoIter, <G as >::IntoIter, <H as >::IntoIter)>

fn from(t: (A, B, C, D, E, F, G, H)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator, E: IntoIterator, F: IntoIterator, G: IntoIterator, H: IntoIterator, I: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter, <E as >::IntoIter, <F as >::IntoIter, <G as >::IntoIter, <H as >::IntoIter, <I as >::IntoIter)>

fn from(t: (A, B, C, D, E, F, G, H, I)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator, E: IntoIterator, F: IntoIterator, G: IntoIterator, H: IntoIterator, I: IntoIterator, J: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter, <E as >::IntoIter, <F as >::IntoIter, <G as >::IntoIter, <H as >::IntoIter, <I as >::IntoIter, <J as >::IntoIter)>

fn from(t: (A, B, C, D, E, F, G, H, I, J)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator, E: IntoIterator, F: IntoIterator, G: IntoIterator, H: IntoIterator, I: IntoIterator, J: IntoIterator, K: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter, <E as >::IntoIter, <F as >::IntoIter, <G as >::IntoIter, <H as >::IntoIter, <I as >::IntoIter, <J as >::IntoIter, <K as >::IntoIter)>

fn from(t: (A, B, C, D, E, F, G, H, I, J, K)) -> Self

impl<A: IntoIterator, B: IntoIterator, C: IntoIterator, D: IntoIterator, E: IntoIterator, F: IntoIterator, G: IntoIterator, H: IntoIterator, I: IntoIterator, J: IntoIterator, K: IntoIterator, L: IntoIterator> From for Zip<(<A as >::IntoIter, <B as >::IntoIter, <C as >::IntoIter, <D as >::IntoIter, <E as >::IntoIter, <F as >::IntoIter, <G as >::IntoIter, <H as >::IntoIter, <I as >::IntoIter, <J as >::IntoIter, <K as >::IntoIter, <L as >::IntoIter)>

fn from(t: (A, B, C, D, E, F, G, H, I, J, K, L)) -> Self

impl<I> IntoIterator for Zip<T>

fn into_iter(self: Self) -> I

impl<IT> MultiUnzip for Zip<T>

fn multiunzip(self: Self)

impl<IT, A, FromA> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA)

impl<IT, A, FromA, B, FromB> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB)

impl<IT, A, FromA, B, FromB, C, FromC> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD, E, FromE> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD, FromE)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD, E, FromE, F, FromF> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD, FromE, FromF)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD, E, FromE, F, FromF, G, FromG> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD, FromE, FromF, FromG)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD, E, FromE, F, FromF, G, FromG, H, FromH> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD, FromE, FromF, FromG, FromH)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD, E, FromE, F, FromF, G, FromG, H, FromH, I, FromI> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD, FromE, FromF, FromG, FromH, FromI)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD, E, FromE, F, FromF, G, FromG, H, FromH, I, FromI, J, FromJ> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD, FromE, FromF, FromG, FromH, FromI, FromJ)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD, E, FromE, F, FromF, G, FromG, H, FromH, I, FromI, J, FromJ, K, FromK> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD, FromE, FromF, FromG, FromH, FromI, FromJ, FromK)

impl<IT, A, FromA, B, FromB, C, FromC, D, FromD, E, FromE, F, FromF, G, FromG, H, FromH, I, FromI, J, FromJ, K, FromK, L, FromL> MultiUnzip for Zip<T>

fn multiunzip(self: Self) -> (FromA, FromB, FromC, FromD, FromE, FromF, FromG, FromH, FromI, FromJ, FromK, FromL)

impl<T> Any for Zip<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Zip<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Zip<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Zip<T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> Freeze for Zip<T>

impl<T> From for Zip<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Itertools for Zip<T>

impl<T> RefUnwindSafe for Zip<T>

impl<T> Send for Zip<T>

impl<T> Sync for Zip<T>

impl<T> ToOwned for Zip<T>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> Unpin for Zip<T>

impl<T> UnsafeUnpin for Zip<T>

impl<T> UnwindSafe for Zip<T>

impl<T, U> Into for Zip<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Zip<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Zip<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::clone::Clone> Clone for Zip<T>

fn clone(self: &Self) -> Zip<T>

impl<T: $crate::fmt::Debug> Debug for Zip<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result