Struct ZipEq
struct ZipEq<I, J> { ... }
An iterator which iterates two other iterators simultaneously and panic if they have different lengths.
See .zip_eq() for more information.
Implementations
impl<I> IntoIterator for ZipEq<I, J>
fn into_iter(self: Self) -> I
impl<I, J> ExactSizeIterator for ZipEq<I, J>
impl<I, J> Freeze for ZipEq<I, J>
impl<I, J> Iterator for ZipEq<I, J>
fn next(self: &mut Self) -> Option<<Self as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<I, J> RefUnwindSafe for ZipEq<I, J>
impl<I, J> Send for ZipEq<I, J>
impl<I, J> Sync for ZipEq<I, J>
impl<I, J> Unpin for ZipEq<I, J>
impl<I, J> UnsafeUnpin for ZipEq<I, J>
impl<I, J> UnwindSafe for ZipEq<I, J>
impl<I: $crate::clone::Clone, J: $crate::clone::Clone> Clone for ZipEq<I, J>
fn clone(self: &Self) -> ZipEq<I, J>
impl<I: $crate::fmt::Debug, J: $crate::fmt::Debug> Debug for ZipEq<I, J>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<IT, A, FromA, B, FromB> MultiUnzip for ZipEq<I, J>
fn multiunzip(self: Self) -> (FromA, FromB)
impl<T> Any for ZipEq<I, J>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ZipEq<I, J>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ZipEq<I, J>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for ZipEq<I, J>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for ZipEq<I, J>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Itertools for ZipEq<I, J>
impl<T> ToOwned for ZipEq<I, J>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for ZipEq<I, J>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ZipEq<I, J>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ZipEq<I, J>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>