Type Alias ConsTuples
type ConsTuples = MapSpecialCase<I, ConsTuplesFn>
An iterator that maps an iterator of tuples like
((A, B), C) to an iterator of (A, B, C).
Used by the iproduct!() macro.
ConsTuplestype ConsTuples = MapSpecialCase<I, ConsTuplesFn>
An iterator that maps an iterator of tuples like
((A, B), C) to an iterator of (A, B, C).
Used by the iproduct!() macro.