Type Alias DedupByWithCount

type DedupByWithCount = CoalesceBy<I, DedupPredWithCount2CoalescePred<Pred>, WithCount>

An iterator adaptor that removes repeated duplicates, while keeping a count of how many repeated elements were present. This will determine equality using a comparison function.

See .dedup_by_with_count() or .dedup_with_count() for more information.