Type Alias MapInto
type MapInto = MapSpecialCase<I, MapSpecialCaseFnInto<R>>
An iterator adapter to apply Into conversion to each element.
See .map_into() for more information.
MapIntotype MapInto = MapSpecialCase<I, MapSpecialCaseFnInto<R>>
An iterator adapter to apply Into conversion to each element.
See .map_into() for more information.