Type Alias MapOk
type MapOk = MapSpecialCase<I, MapSpecialCaseFnOk<F>>
An iterator adapter to apply a transformation within a nested Result::Ok.
See .map_ok() for more information.
MapOktype MapOk = MapSpecialCase<I, MapSpecialCaseFnOk<F>>
An iterator adapter to apply a transformation within a nested Result::Ok.
See .map_ok() for more information.