Enum Diff

enum Diff<I, J>
where
    I: Iterator,
    J: Iterator

A type returned by the diff_with function.

Diff represents the way in which the elements yielded by the iterator I differ to some iterator J.

Variants

FirstMismatch(usize, crate::structs::PutBack<I>, crate::structs::PutBack<J>)

The index of the first non-matching element along with both iterator's remaining elements starting with the first mis-match.

Shorter(usize, crate::structs::PutBack<I>)

The total number of elements that were in J along with the remaining elements of I.

Longer(usize, crate::structs::PutBack<J>)

The total number of elements that were in I along with the remaining elements of J.

Implementations

impl<I, J> Clone for Diff<I, J>

fn clone(self: &Self) -> Self

impl<I, J> Debug for Diff<I, J>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<I, J> Freeze for Diff<I, J>

impl<I, J> RefUnwindSafe for Diff<I, J>

impl<I, J> Send for Diff<I, J>

impl<I, J> Sync for Diff<I, J>

impl<I, J> Unpin for Diff<I, J>

impl<I, J> UnsafeUnpin for Diff<I, J>

impl<I, J> UnwindSafe for Diff<I, J>

impl<T> Any for Diff<I, J>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Diff<I, J>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Diff<I, J>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Diff<I, J>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Diff<I, J>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Diff<I, J>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Diff<I, J>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Diff<I, J>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Diff<I, J>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>