pub enum FoldWhile<T> {
Continue(T),
Done(T),
}Expand description
An enum used for controlling the execution of .fold_while().
See .fold_while() for more information.
Continue folding with this value
Fold is complete and will return this value
Return the value in the continue or done.
Return true if self is Done, false if it is Continue.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.