Function concat
fn concat<I>(iterable: I) -> <I as >::Item
where
I: IntoIterator,
<I as >::Item: Extend<<<I as IntoIterator>::Item as IntoIterator>::Item> + IntoIterator + Default
Combine all an iterator's elements into one element by using Extend.
IntoIterator-enabled version of Itertools::concat.
This combinator will extend the first item with each of the rest of the
items of the iterator. If the iterator is empty, the default value of
I::Item is returned.
use concat;
let input = vec!;
assert_eq!;