Struct Format
struct Format<'a, I> { ... }
Format all iterator elements lazily, separated by sep.
The format value can only be formatted once, after that the iterator is exhausted.
See .format()
for more information.
Implementations
impl<'a, I> Binary for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, I> Debug for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, I> Display for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, I> Freeze for Format<'a, I>
impl<'a, I> LowerExp for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, I> LowerHex for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, I> Octal for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, I> Pointer for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, I> RefUnwindSafe for Format<'a, I>
impl<'a, I> Send for Format<'a, I>
impl<'a, I> Sync for Format<'a, I>
impl<'a, I> Unpin for Format<'a, I>
impl<'a, I> UnsafeUnpin for Format<'a, I>
impl<'a, I> UnwindSafe for Format<'a, I>
impl<'a, I> UpperExp for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, I> UpperHex for Format<'a, I>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<I> Clone for Format<'_, I>
fn clone(self: &Self) -> Self
impl<T> Any for Format<'a, I>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Format<'a, I>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Format<'a, I>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Format<'a, I>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Format<'a, I>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Format<'a, I>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for Format<'a, I>
fn to_string(self: &Self) -> String
impl<T, U> Into for Format<'a, I>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Format<'a, I>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Format<'a, I>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>